<?php
/**
 * fFengShui functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @subpackage fFengShui
 * @author tishonator
 * @since fFengShui 1.0.0
 *
 */

if ( ! function_exists( 'ffengshui_setup' ) ) :
/**
 * fFengShui setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 */
function ffengshui_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 */
	load_theme_textdomain( 'ffengshui', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 0, true );

	// This theme uses wp_nav_menu() in header menu
	register_nav_menus( array(
		'primary'   => __( 'primary menu', 'ffengshui' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	

	// add the visual editor to resemble the theme style
	add_editor_style( array( 'css/editor-style.css' ) );

	// add custom background				 
	add_theme_support( 'custom-background', 
				   array ('default-color'  => '#FFFFFF')
				 );

	// add content width
	if ( ! isset( $content_width ) ) {
		$content_width = 900;
	}

	// add custom header
	add_theme_support( 'custom-header', array (
					   'default-image'          => '',
					   'random-default'         => '',
					   'width'                  => 145,
					   'height'                 => 36,
					   'flex-height'            => true,
					   'flex-width'             => true,
					   'default-text-color'     => '',
					   'header-text'            => '',
					   'uploads'                => true,
					   'wp-head-callback'       => '',
					   'admin-head-callback'    => '',
					   'admin-preview-callback' => '',
					) );

}
endif; // ffengshui_setup
add_action( 'after_setup_theme', 'ffengshui_setup' );

/**
 * the main function to load scripts in the fFengShui theme
 * if you add a new load of script, style, etc. you can use that function
 * instead of adding a new wp_enqueue_scripts action for it.
 */
function ffengshui_load_scripts() {

	// load styles.
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', array() );
	wp_enqueue_style( 'ffengshui-style', get_stylesheet_uri(), array() );
	
	wp_enqueue_style( 'ffengshui-fonts', ffengshui_fonts_url(), array(), null );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	// Load Utilities JS Script
	wp_enqueue_script( 'bjqs', get_template_directory_uri() . '/js/bjqs-1.3.min.js', array( 'jquery' ) );

	wp_enqueue_script( 'ffengshui-js', get_template_directory_uri() . '/js/utilities.js', array( 'jquery' ) );
}

add_action( 'wp_enqueue_scripts', 'ffengshui_load_scripts' );

/**
 *	Load google font url used in the fFengShui theme
 */
function ffengshui_fonts_url() {

    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by PT Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $ptsans = _x( 'on', 'PT Sans font: on or off', 'ffengshui' );

    if ( 'off' !== $ptsans ) {
        $font_families = array();
 
        $font_families[] = 'PT Sans';
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,cyrillic-ext,cyrillic,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}

/**
 * Display website's logo image
 */
function ffengshui_show_website_logo_image_or_title() {

	if ( get_header_image() != '' ) {
	
		// Check if the user selected a header Image in the Customizer or the Header Menu
		$logoImgPath = get_header_image();
		$siteTitle = get_bloginfo( 'name' );
		$imageWidth = get_custom_header()->width;
		$imageHeight = get_custom_header()->height;
		
		echo '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo('name') ) . '">';
		
		echo '<img src="' . esc_url( $logoImgPath ) . '" alt="' . esc_attr( $siteTitle ) . '" title="' . esc_attr( $siteTitle ) . '" width="' . esc_attr( $imageWidth ) . '" height="' . esc_attr( $imageHeight ) . '" />';
		
		echo '</a>';

	} else {
	
		echo '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo('name') ) . '">';
		
		echo '<h1>'.get_bloginfo('name').'</h1>';
		
		echo '</a>';
		
		echo '<strong>'.get_bloginfo('description').'</strong>';
	}
}

/**
 *	Displays the copyright text.
 */
function ffengshui_show_copyright_text() {

	$footerText = get_theme_mod('ffengshui_footer_copyright', null);

	if ( !empty( $footerText ) ) {

		echo esc_html( $footerText ) . ' | ';		
	}
}

/**
 *	widgets-init action handler. Used to register widgets and register widget areas
 */
function ffengshui_widgets_init() {
	
	// Register Sidebar Widget.
	register_sidebar( array (
						'name'	 		 =>	 __( 'Sidebar Widget Area', 'ffengshui'),
						'id'		 	 =>	 'sidebar-widget-area',
						'description'	 =>  __( 'The sidebar widget area', 'ffengshui'),
						'before_widget'	 =>  '',
						'after_widget'	 =>  '',
						'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
						'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
					) );
}

add_action( 'widgets_init', 'ffengshui_widgets_init' );

/**
 * Displays the slider
 */
function ffengshui_display_slider() { ?>

<?php
	/**
	 *	Check if slider should be displayed
	 *
	 * Note: the slider will be displayed if there's at least one slider image set
	 */
	$displaySlider = false;
	for ( $i = 1; $i <= 3; ++$i ) {

		$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
		$slideImage = get_theme_mod( 'ffengshui_slide'.$i.'_image', $defaultSlideImage );

		if (!empty($slideImage)) {
			$displaySlider = true;
			break;
		}
	}

	// if no images set for slider, skip displaying it
	if (!$displaySlider) {
		return;
	}
?>
	<div id="banner-wrapper">
		<div id="banner-fade">
			<ul class="bjqs">
			<?php
				// display slides
				for ( $i = 1; $i <= 3; ++$i ) {

					$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
					$slideImage = get_theme_mod( 'ffengshui_slide'.$i.'_image', $defaultSlideImage );
				?>

					<?php if ( !empty($slideImage) ) : ?>

							<li>
								<img src="<?php echo esc_url($slideImage); ?>" />
							</li>

					<?php endif; ?>
			<?php	
				}
			?>
			</ul>
		</div><!-- #banner-fade -->
		<div class="clear">
		</div>
	</div>
<?php  
}

/**
 * Register theme settings in the customizer
 */
function ffengshui_customize_register( $wp_customize ) {

	/**
	 * Add Slider Section
	 */
	$wp_customize->add_section(
		'ffengshui_slider_section',
		array(
			'title'       => __( 'Slider', 'ffengshui' ),
			'capability'  => 'edit_theme_options',
		)
	);


	for ( $i = 1; $i <= 3; ++$i ) {

		$slideContentId = 'ffengshui_slide' . $i . '_title';
		$slideImageId = 'ffengshui_slide' . $i . '_image';
		$slideDefaultImagePath = get_template_directory_uri().'/images/slider/' . $i . '.jpg';
		$slideLabelImage = sprintf( __( 'Slide #%s Image', 'ffengshui' ), $i );

		// Add slide # background image
		$wp_customize->add_setting( $slideImageId,
			array(
				'default' => $slideDefaultImagePath,
	    		'sanitize_callback' => 'esc_url_raw'
			)
		);

	    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $slideImageId,
				array(
					'label'   	 => $slideLabelImage,
					'section' 	 => 'ffengshui_slider_section',
					'settings'   => $slideImageId,
				) 
			)
		);
	}

	/**
	 * Add Footer Section
	 */
	$wp_customize->add_section(
		'ffengshui_footer_section',
		array(
			'title'       => __( 'Footer', 'ffengshui' ),
			'capability'  => 'edit_theme_options',
		)
	);
	
	// Add footer copyright text
	$wp_customize->add_setting(
		'ffengshui_footer_copyright',
		array(
		    'default'           => '',
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'ffengshui_footer_copyright',
        array(
            'label'          => __( 'Copyright Text', 'ffengshui' ),
            'section'        => 'ffengshui_footer_section',
            'settings'       => 'ffengshui_footer_copyright',
            'type'           => 'text',
            )
        )
	);
}

add_action('customize_register', 'ffengshui_customize_register');

/*
Enqueue Script for top buttons
*/
function ffengshui_customizer_controls(){

	wp_register_script( 'ffengshui_customizer_top_buttons', get_template_directory_uri() . '/js/customizer-top-buttons.js', array( 'jquery' ), true  );
	wp_enqueue_script( 'ffengshui_customizer_top_buttons' );

	wp_localize_script( 'ffengshui_customizer_top_buttons', 'customBtns', array(
		'prodemo' => esc_html__( 'Demo Premium version', 'ffengshui' ),
        'proget' => esc_html__( 'Get Premium version', 'ffengshui' )
	) );
}
add_action( 'customize_controls_enqueue_scripts', 'ffengshui_customizer_controls' );

?>
